" Vim syntax file
" Language:   PROLOG
" Maintainers:   Ralph Becket <rwab1@cam.sri.co.uk>,
"                Thomas Koehler <jean-luc@picard.franken.de>
" Last change:   1997 July 17

" There are two sets of highlighting in here:
" If the "prolog_highlighting_clean" variable exists, it is rather sparse.
" Otherwise you get a lot of highlighting.

" Remove any old syntax stuff hanging around.
syn clear

" Prolog is case sensitive.
syn case match

syn region	prologCComment      start=+/\*+ end=+\*/+
syn match	prologComment      +%.*+

if exists("prolog_highlighting_clean")

  "Ralph's bit.
  "
  " Very simple highlighting for comments, clause heads and
  " character codes.  It respects prolog strings and atoms.

  syn keyword  prologKeyword		module meta_predicate multifile dynamic
  syn match    prologCharCode	+0'\\\=.+
  syn region   prologString		start=+"+ skip=+\\"+ end=+"+
  syn region   prologAtom		start=+'+ skip=+\\'+ end=+'+
  syn region   prologClauseHead	start=+^[a-z][^(]*(+ end=+:-\|\.\|-->+

else

  "Thomas' bit.

  syn keyword prologStatement  import findall repeat listelement
  syn keyword prologLabel      delete write nl append read get get0

  " String and Character contstants
  syn match   prologConstant "[a-z][^ ()=\[\]\.]*"
  syn match   prologVariable "[A-Z][^ ()=\[\]\.]*"
  syn match  prologNumber              "[0123456789]*"

  syn match  prologCommentError        "\*/"
  syn region  prologSpecialCharacter  start=+\[+  end=+\]+  contains=prologVariable,prologConstant,prologNumber,prologComment
  syn match   prologSpecialCharacter  ","
  syn region  prologString               start=+:-+  end=+\.+  contains=prologVariable,prologNumber,prologSpecialCharacter,prologComment
  syn region  prologCharacter    start=+?-+  end=+\.+  contains=prologVariable,prologNumber,prologSpecialCharacter,prologComment

  syn match   prologRepeat  "\."

endif

syn sync ccomment maxlines=50

if !exists("did_prolog_syntax_inits")

  let did_prolog_syntax_inits = 1

  " The default methods for highlighting.  Can be overridden later

  hi link prologComment		Comment
  hi link prologCComment		Comment

  if exists ("prolog_highlighting_clean")

    hi link prologKeyword	Statement
    hi link prologCharCode	Special
    hi link prologClauseHead	Statement

  else

    hi link prologLabel            prologStatement
    hi link prologRepeat   prologVariable
    hi link prologCharacter        prologIdentifier
    hi link prologSpecialCharacter prologVariable
    hi link prologNumber   prologString
    hi link prologCommentError     prologError
    hi link prologConstant prologStatement
    hi link prologError            Error
    hi link prologStatement        Statement
    hi link prologString   String
    hi link prologVariable  Special
    hi link prologIdentifier       Identifier

  endif

endif

let b:current_syntax = "prolog"

" vim: ts=8
